<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ijw="http://www.istandaarden.nl/ijw/2_4/basisschema/schema"
	xmlns:jw304="http://www.istandaarden.nl/ijw/2_4/jw304/schema"
	>

	<!-- iJw 2.4 TR320 version 1.9.14 (2019-12-02) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR320"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR320"/>
	</xsl:template>

	<xsl:template match="jw304:RetourBedragen" mode="TR320">
		<!-- Bereken SaldoIngediendeBedragregel -->
		<xsl:variable name="IngediendTotaalDebet" select="sum(ancestor-or-self::jw304:Bericht/jw304:Clienten/jw304:Client/jw304:Prestaties/jw304:Prestatie/jw304:IngediendeBedragPrestatie/ijw:DeclaratieFactuurBedrag[ijw:DebetCredit = 'D']/ijw:Bedrag)"/>
		<xsl:variable name="IngediendTotaalCredit" select="sum(ancestor-or-self::jw304:Bericht/jw304:Clienten/jw304:Client/jw304:Prestaties/jw304:Prestatie/jw304:IngediendeBedragPrestatie/ijw:DeclaratieFactuurBedrag[ijw:DebetCredit = 'C']/ijw:Bedrag)"/>
		<xsl:variable name="SaldoIngediendeBedragregel" select="$IngediendTotaalDebet - $IngediendTotaalCredit"/>

		<!-- Bereken SaldoToegekendeBedragregel -->
		<xsl:variable name="ToegekendTotaalDebet" select="sum(ancestor-or-self::jw304:Bericht/jw304:Clienten/jw304:Client/jw304:Prestaties/jw304:Prestatie/jw304:ToegekendeBedragPrestatie/ijw:ToegekendBedrag[ijw:DebetCredit = 'D']/ijw:Bedrag)"/>
		<xsl:variable name="ToegekendTotaalCredit" select="sum(ancestor-or-self::jw304:Bericht/jw304:Clienten/jw304:Client/jw304:Prestaties/jw304:Prestatie/jw304:ToegekendeBedragPrestatie/ijw:ToegekendBedrag[ijw:DebetCredit = 'C']/ijw:Bedrag)"/>
		<xsl:variable name="SaldoToegekendeBedragregel" select="$ToegekendTotaalDebet - $ToegekendTotaalCredit"/>

		<!-- Bepaal verschil E: = SaldoIngediendeBedragregel minus SaldoToegekende bedragregel-->
		<xsl:variable name="VerschilBedragregel" select="$SaldoIngediendeBedragregel - $SaldoToegekendeBedragregel"/>

		<!-- Maak van ToegekendTotaalBedrag een negatief getal als ToegekendDebetCredit waarde C heeft -->
		<xsl:variable name="ToegekendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./ijw:ToegekendTotaalBedrag/ijw:DebetCredit/text() = 'C' ">
					<xsl:value-of select='./ijw:ToegekendTotaalBedrag/ijw:TotaalBedrag/text() * -1'/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select='./ijw:ToegekendTotaalBedrag/ijw:TotaalBedrag/text()'/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Maak van IngediendTotaalBedrag een negatief getal als IngediendDebetCredit waarde C heeft -->
		<xsl:variable name="IngediendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./ijw:IngediendTotaalBedrag/ijw:DebetCredit/text() = 'C' ">
					<xsl:value-of select='./ijw:IngediendTotaalBedrag/ijw:TotaalBedrag/text() * -1'/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select='./ijw:IngediendTotaalBedrag/ijw:TotaalBedrag/text()'/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Bepaal verschil F:= IngediendTotaalBedrag minus ToegekendTotaalBedrag-->
		<xsl:variable name="VerschilHeaderTotalen" select="$IngediendTotaalBedragDC - $ToegekendTotaalBedragDC"/>

		<!-- Controleren of verschil E overeenkomt met verschil F bedragen -->
		<xsl:if test="count(ancestor-or-self::jw304:Bericht/jw304:Header/jw304:RetourCodes/*[local-name() = 'RetourCode'][text() != '0200' and text() != '8001']) = 0 and normalize-space($VerschilBedragregel) != normalize-space($VerschilHeaderTotalen)">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR320</xsl:with-param>
				<xsl:with-param name="pCode">0001</xsl:with-param>
				<xsl:with-param name="pElements" select="
					ijw:IngediendTotaalBedrag/ijw:TotaalBedrag | ijw:IngediendTotaalBedrag/ijw:DebetCredit |
					ijw:ToegekendTotaalBedrag/ijw:TotaalBedrag | ijw:ToegekendTotaalBedrag/ijw:DebetCredit"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
